﻿using ProjectSellPC.Repos;
using Unity;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ProjectSellPC.Forms.Receipt
{
    public partial class ChequeForm : Form
    {
        private readonly IUnityContainer _container;
        private readonly IChequeRepository _ChequeRepository;
        private readonly IClientRepository _clientRepository;
        private readonly IProductRepository _productRepository; // Добавляем репозиторий товаров

        public ChequeForm(IUnityContainer unityContainer, IChequeRepository ChequeRepository, IClientRepository clientRepository, IProductRepository productRepository)
        {
            InitializeComponent();

            _container = unityContainer ?? throw new ArgumentNullException(nameof(unityContainer));
            _ChequeRepository = ChequeRepository ?? throw new ArgumentNullException(nameof(ChequeRepository));
            _clientRepository = clientRepository ?? throw new ArgumentNullException(nameof(clientRepository));
            _productRepository = productRepository ?? throw new ArgumentNullException(nameof(productRepository)); // Инициализация репозитория товаров
        }
        private void ChequeForm_Load(object sender, EventArgs e)
        {
            try
            {
                LoadList();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при загрузке", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private void LoadList()
        {
            try
            {
                // Получаем все чеки и удаляем дубликаты по ID
                var cheques = _ChequeRepository.ReadAll()
                    .GroupBy(c => c.Id)
                    .Select(g => g.First())
                    .ToList();

                // Загружаем информацию о клиентах
                foreach (var cheque in cheques)
                {
                    cheque.Client = _clientRepository.Read(cheque.ClientId);

                    // Загружаем названия товаров для каждого чека
                    foreach (var productInCheque in cheque.Products)
                    {
                        var product = _productRepository.Read(productInCheque.ProductID);
                        productInCheque.ProductName = product?.Name ?? "Неизвестный товар";
                    }
                }

                // Привязываем данные к DataGridView
                ChequesDataGridView.DataSource = cheques.Select(c => new
                {
                    Id = c.Id,
                    ClientName = c.Client?.Name ?? "Неизвестно",
                    PurchaseDate = c.PurchaseDate,
                    Products = string.Join(", ", c.Products.Select(p => p.ProductName)), // Названия товаров через запятую
                    Quantities = string.Join(", ", c.Products.Select(p => p.Count.ToString())) // Количество товаров через запятую
                }).ToList();

                // Настройка столбцов DataGridView
                ChequesDataGridView.Columns["Id"].HeaderText = "ID";
                ChequesDataGridView.Columns["ClientName"].HeaderText = "Клиент";
                ChequesDataGridView.Columns["PurchaseDate"].HeaderText = "Дата покупки";
                ChequesDataGridView.Columns["Products"].HeaderText = "Товары";
                ChequesDataGridView.Columns["Quantities"].HeaderText = "Количество";
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при загрузке", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private void addButton_Click(object sender, EventArgs e)
        {
            try
            {
                _container.Resolve<ChequeSettingsForm>().ShowDialog();
                LoadList();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при добавлении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
    }
}
