﻿using ProjectSellPC.Entites.Enums;
using ProjectSellPC.Entites;
using ProjectSellPC.Repos;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;     

namespace ProjectSellPC.Forms.Clients
{
    public partial class ClientFormSettings : Form
    {
        private readonly IClientRepository _repository;

        private int? _clientId;

        public int Id
        {
            set
            {
                try
                {
                    var client = _repository.Read(value);
                    if (client == null)
                    {
                        throw new InvalidDataException(nameof(client));
                    }
                    nameTextbox.Text = client.Name;
                    phoneNumberTextbox.Text = client.PhoneNumber;
                    typeCombobox.SelectedItem = client.ClientType;

                    _clientId = value;
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Ошибка при данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }
        }

        public ClientFormSettings(IClientRepository clientRepository)
        {
            InitializeComponent();
            _repository = clientRepository ?? throw new ArgumentNullException(nameof(clientRepository));
            typeCombobox.DataSource = Enum.GetValues(typeof(ClientType));

        }

        private void ClientFormSettings_Load(object sender, EventArgs e)
        {

        }

        private void saveButton_Click(object sender, EventArgs e)
        {
            try
            {
                if (string.IsNullOrWhiteSpace(nameTextbox.Text) ||
                 string.IsNullOrWhiteSpace(phoneNumberTextbox.Text) || typeCombobox.SelectedIndex < 1
                 || typeCombobox.SelectedIndex < 1)
                {
                    throw new Exception("Имеются незаполненные поля");
                }

                if (_clientId.HasValue)
                {

                    _repository.Update(CreateClient(_clientId.Value));
                }
                else
                {

                    _repository.Create(CreateClient(0));
                }

                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении",
            MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private Client CreateClient(int id)
        {
            return Client.CreateEntity(id, nameTextbox.Text, phoneNumberTextbox.Text, (ClientType)typeCombobox.SelectedValue);
        }

    }
}
