﻿using System;
using ProjectSellPC.Repos;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Unity;
using ProjectSellPC.DocBuilder;

namespace ProjectSellPC.Forms.DocReports
{
    public partial class ExcelReportForm : Form
    {
        private readonly IUnityContainer _container;

        public ExcelReportForm(IUnityContainer container, IProductRepository productRepository)
        {
            InitializeComponent();

            _container = container ?? throw new ArgumentNullException(nameof(container));

            productCombobox.DataSource = productRepository.ReadAll();
            productCombobox.DisplayMember = "Name";
            productCombobox.ValueMember = "Id";
        }


        private void formButton_Click(object sender, EventArgs e)
        {
            try
            {
                if (string.IsNullOrWhiteSpace(pathTextbox.Text))
                {
                    throw new Exception("Отсутствует имя файла для отчета");
                }

                if (productCombobox.SelectedIndex < 0)
                {
                    throw new Exception("Не выбран товар");
                }

                if (dateTimePickerDo.Value <= dateTimePickerOt.Value)
                {
                    throw new Exception("Дата начала должна быть раньше даты окончания");
                }

                if (_container.Resolve<TableReport>().CreateTable(pathTextbox.Text,
                    (int)productCombobox.SelectedValue!,
                    dateTimePickerOt.Value, dateTimePickerDo.Value))
                {
                    MessageBox.Show("Документ сформирован", "Формирование документа",
                     MessageBoxButtons.OK,
                        MessageBoxIcon.Information);
                }
                else
                {
                    MessageBox.Show("Возникли ошибки при формировании документа.Подробности в логах", "Формирование документа",
                        MessageBoxButtons.OK, MessageBoxIcon.Information);
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при создании очета",
            MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void pathChoiceButton_Click(object sender, EventArgs e)
        {
            var sfd = new SaveFileDialog()
            {
                Filter = "Excel Files | *.xlsx"
            };

            if (sfd.ShowDialog() != DialogResult.OK)
            {
                return;
            }

            pathTextbox.Text = sfd.FileName;
        }
    }
}
