﻿using ProjectSellPC.Repos;
using Unity;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ProjectSellPC
{
    public partial class ProductForm : Form
    {
        private readonly IUnityContainer _container;
        private readonly IProductRepository _productRepository;

        public ProductForm(IUnityContainer unityContainer, IProductRepository productRepository)
        {
            InitializeComponent();

            _container = unityContainer ?? throw new ArgumentNullException(nameof(unityContainer));
            _productRepository = productRepository ?? throw new ArgumentNullException(nameof(_productRepository));
        }

        private void ProductForm_Load(object sender, EventArgs e)
        {
            try
            {
                LoadList();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при загрузке", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private void LoadList()
        {

            productsDataGridView.DataSource = _productRepository.ReadAll();
            productsDataGridView.Columns["ID"].Visible = false;
        }

        private bool TryGetIdentifierFromSelectedRow(out int id)
        {
            id = 0;
            if (productsDataGridView.SelectedRows.Count < 1)
            {
                MessageBox.Show("Нет выбранной записи", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return false;
            }

            id = Convert.ToInt32(productsDataGridView.SelectedRows[0].Cells["Id"].Value);
            return true;
        }

        private void addButton_Click(object sender, EventArgs e)
        {
            try
            {
                _container.Resolve<ProductSettingsForm>().ShowDialog();
                LoadList();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при добавлении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void editButton_Click(object sender, EventArgs e)
        {
            if (!TryGetIdentifierFromSelectedRow(out var findId))
            {
                return;
            }

            try
            {
                var form = _container.Resolve<ProductSettingsForm>();
                form.Id = findId;
                form.ShowDialog();
                LoadList();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при изменении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void deleteButton_Click(object sender, EventArgs e)
        {
            if (!TryGetIdentifierFromSelectedRow(out var findId))
            {
                return;
            }

            if (MessageBox.Show("Удалить запись?", "Удаление", MessageBoxButtons.YesNo) != DialogResult.Yes)
            {
                return;
            }

            try
            {
                _productRepository.Delete(findId);
                LoadList();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при удалении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
    }
}
