﻿using ProjectSellPC.Entites;
using ProjectSellPC.Entites.Enums;
using ProjectSellPC.Repos;
using Microsoft.VisualBasic.FileIO;
using System;
using System.Windows.Forms;

namespace ProjectSellPC
{
    public partial class ProductSettingsForm : Form
    {
        private readonly IProductRepository _productRepository;

        private int? _productId;

        public int Id
        {
            set
            {
                try
                {
                    var product = _productRepository.Read(value);
                    if (product == null)
                    {
                        throw new InvalidDataException(nameof(product));
                    }
                    productNameTextbox.Text = product.Name;
                    descriptionTextbox.Text = product.Description;
                    foreach (ProductType elem in Enum.GetValues(typeof(ProductType)))
                    {
                        if ((elem & product.ProductType) != 0)
                        {

                            typeChequeedListBox.SetItemChecked(typeChequeedListBox.Items.IndexOf(elem), true);
                        }
                    }
                    priceNumeric.Value = product.Price;
                    _productId = value;
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Ошибка при данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }
        }

        public ProductSettingsForm(IProductRepository productRepository)
        {
            InitializeComponent();
            _productRepository = productRepository ?? throw new ArgumentNullException(nameof(productRepository));


            foreach (var elem in Enum.GetValues(typeof(ProductType)))
            {
                typeChequeedListBox.Items.Add(elem);
            }

        }

        private void ProductSettingsForm_Load(object sender, EventArgs e)
        {

        }

        private void saveButton_Click(object sender, EventArgs e)
        {
            try
            {
                if (string.IsNullOrWhiteSpace(productNameTextbox.Text) ||
                 string.IsNullOrWhiteSpace(descriptionTextbox.Text) || typeChequeedListBox.CheckedItems.Count == 0)
                {
                    throw new Exception("Имеются незаполненные поля");
                }

                if (_productId.HasValue)
                {

                    _productRepository.Update(CreateProduct(_productId.Value));
                }
                else
                {

                    _productRepository.Create(CreateProduct(0));
                }

                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении",
            MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private Product CreateProduct(int id)
        {
            ProductType type = ProductType.None;
            foreach (var elem in typeChequeedListBox.CheckedItems)
            {
                type |= (ProductType)elem;
            }

            return Product.CreateEntity(id, productNameTextbox.Text, descriptionTextbox.Text, priceNumeric.Value, type);
        }

    }
}
