﻿using ProjectSellPC.Entites;
using ProjectSellPC.Repos;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ProjectSellPC.Forms.ProductsOnWarehouse
{
    public partial class ProductsOnWarehouseSettingsForm : Form
    {
        private readonly IProductOnWarehouseRepository _productOnWarehouseRepository;
        private readonly IProductRepository _productRepository;
        private readonly IWarehouseRepository _WarehouseRepository;

        private int? _recordId;

        public int Id
        {
            set
            {
                try
                {
                    var record = _productOnWarehouseRepository.Read(value);
                    if (record == null)
                    {
                        throw new InvalidDataException("Record not found");
                    }
                    //ProductComboBox
                    foreach (var item in _productRepository.ReadAll())
                    {
                        if (item.ID == record.ProductId)
                        {
                            productCombobox.SelectedItem = item;
                        }
                    }
                    //WarehouseCombobox
                    foreach (var item in _WarehouseRepository.ReadAll())
                    {
                        if (item.Id == record.WarehouseId)
                        {
                            WarehouseCombobox.SelectedItem = item;
                        }
                    }
                    countNumeric.Value = record.Count;
                    _recordId = value;
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Ошибка при загрузке данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }

        public ProductsOnWarehouseSettingsForm(
            IProductOnWarehouseRepository productOnWarehouseRepository,
            IProductRepository productRepository,
            IWarehouseRepository WarehouseRepository)
        {
            InitializeComponent();

            _productOnWarehouseRepository = productOnWarehouseRepository ?? throw new ArgumentNullException(nameof(productOnWarehouseRepository));
            _productRepository = productRepository ?? throw new ArgumentNullException(nameof(productRepository));
            _WarehouseRepository = WarehouseRepository ?? throw new ArgumentNullException(nameof(WarehouseRepository));

            LoadComboboxes();
        }
        private void ProductsOnWarehouseSettingsForm_Load(object sender, EventArgs e)
        {

        }
        private void LoadComboboxes()
        {
            productCombobox.DataSource = _productRepository.ReadAll().ToList();
            productCombobox.DisplayMember = "Name";
            productCombobox.ValueMember = "Id";

            WarehouseCombobox.DataSource = _WarehouseRepository.ReadAll().ToList();
            WarehouseCombobox.DisplayMember = "Adress";
            //WarehouseCombobox.ValueMember = "Id";
        }

        private void saveButton_Click(object sender, EventArgs e)
        {
            try
            {
                if (productCombobox.SelectedItem == null || WarehouseCombobox.SelectedItem == null)
                {
                    throw new Exception("Заполните все поля");
                }

                var selectedProduct = (Product)productCombobox.SelectedItem;
                var selectedWarehouse = (Entites.Warehouse)WarehouseCombobox.SelectedItem;
                var count = (int)countNumeric.Value;
                _productOnWarehouseRepository.Create(CreateProductOnWarehouse(0, selectedProduct, selectedWarehouse, count));
                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private Entites.ProductsOnWarehouse CreateProductOnWarehouse(int id, Product product, Entites.Warehouse Warehouse, int count)
        {
            return Entites.ProductsOnWarehouse.CreateEntity(id, product, Warehouse, count);
        }
    }
}
