using ProjectSellPC.Repos;
using ProjectSellPC.Repos.Impements;
using Microsoft.Extensions.Logging;
using Unity;
using Unity.Lifetime;
using Serilog;
using Microsoft.Extensions.Configuration;

namespace ProjectSellPC
{
    internal static class Program
    {
        /// <summary>
        ///  The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main()
        {
            ApplicationConfiguration.Initialize();
            Application.Run(CreateContainer().Resolve<ShopForm>());
        }
        private static IUnityContainer CreateContainer()
        {
            var container = new UnityContainer();

            container.RegisterInstance<ILoggerFactory>(CreateLoggerFactory());

            container.RegisterType<IConnectionString, ConnectionString>(new SingletonLifetimeManager());

            container.RegisterType<IProductRepository, ProductRepo>(new TransientLifetimeManager());
            container.RegisterType<IClientRepository, ClientRepo>(new TransientLifetimeManager());
            container.RegisterType<IWarehouseRepository, WarehouseRepo>(new TransientLifetimeManager());
            container.RegisterType<IProductOnWarehouseRepository, ProductsOnWarehouseRepo>(new TransientLifetimeManager());
            container.RegisterType<IProductInChequeRepository, ProductInChequeRepo>(new TransientLifetimeManager());
            container.RegisterType<IChequeRepository, ChequeRepo>(new TransientLifetimeManager());

            return container;
        }
        private static LoggerFactory CreateLoggerFactory()
        {
            var loggerFactory = new LoggerFactory();
            loggerFactory.AddSerilog(new LoggerConfiguration()
             .ReadFrom.Configuration(new ConfigurationBuilder()
              .SetBasePath(Directory.GetCurrentDirectory())
              .AddJsonFile("appsettings.json")
              .Build())
             .CreateLogger());
            return loggerFactory;
        }
    }
}