﻿using ProjectSellPC.Entites;
using Dapper;
using Microsoft.Extensions.Logging;
using Newtonsoft.Json;
using Npgsql;
using System;
using System.Collections.Generic;
using System.Data;
using System.Linq;

namespace ProjectSellPC.Repos.Impements
{
    public class WarehouseRepo: IWarehouseRepository
    {
        private readonly IConnectionString _connectionString;
        private readonly ILogger<WarehouseRepo> _logger;

        public WarehouseRepo(IConnectionString connectionString, ILoggerFactory loggerFactory)
        {
            _connectionString = connectionString;
            _logger = loggerFactory.CreateLogger<WarehouseRepo>();
        }

        private IDbConnection CreateConnection() => new NpgsqlConnection(_connectionString.ConnectionString);

        public void Create(Warehouse warehouse)
        {
            _logger.LogInformation("Добавление склада");
            _logger.LogDebug("Склад: {json}", JsonConvert.SerializeObject(warehouse));

            try
            {
                using (var connection = CreateConnection())
                {
                    var sql = "INSERT INTO \"warehouse\" (\"size\", \"adress\") " +
                              "VALUES (@Size, @Adress)";

                    connection.Execute(sql, new
                    {
                        Size = warehouse.Size,
                        Adress = warehouse.Adress
                    });
                }
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка при добавлении склада");
                throw;
            }
        }

        public void Delete(int id)
        {
            _logger.LogInformation("Удаление склада");
            _logger.LogDebug("Склад ID: {id}", id);

            try
            {
                using (var connection = CreateConnection())
                {
                    var sql = "DELETE FROM \"warehouse\" WHERE \"id\" = @Id";
                    connection.Execute(sql, new { Id = id });
                }
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка при удалении склада");
                throw;
            }
        }

        public Warehouse Read(int id)
        {
            _logger.LogInformation("Получение склада по ID");
            _logger.LogDebug("Склад ID: {id}", id);

            try
            {
                using (var connection = CreateConnection())
                {
                    var sql = "SELECT * FROM \"warehouse\" WHERE \"id\" = @Id";
                    return connection.QuerySingleOrDefault<Warehouse>(sql, new { Id = id });
                }
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка при получении склада");
                throw;
            }
        }

        public IEnumerable<Warehouse> ReadAll()
        {
            _logger.LogInformation("Получение всех складов");

            try
            {
                using (var connection = CreateConnection())
                {
                    var sql = "SELECT * FROM \"warehouse\"";
                    return connection.Query<Warehouse>(sql).ToList();
                }
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка при получении списка складов");
                throw;
            }
        }

        public Warehouse Update(Warehouse warehouse)
        {
            _logger.LogInformation("Обновление информации о складе");
            _logger.LogDebug("Склад: {json}", JsonConvert.SerializeObject(warehouse));

            try
            {
                using (var connection = CreateConnection())
                {
                    var sql = "UPDATE \"warehouse\" SET \"size\" = @Size, \"adress\" = @Adress " +
                              "WHERE \"id\" = @Id";

                    connection.Execute(sql, new
                    {
                        Id = warehouse.Id,
                        Size = warehouse.Size,
                        Adress = warehouse.Adress
                    });

                    return warehouse;
                }
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка при обновлении информации о складе");
                throw;
            }
        }
    }
}
